package com.ruoyi.mall.mapper;

import java.util.List;
import java.util.Map;

import com.ruoyi.mall.domain.MallCareer;
import org.apache.ibatis.annotations.Param;

/**
 * 职业Mapper接口
 *
 * @author LCL
 * @date 2023-10-19
 */
public interface MallCareerMapper
{
    /**
     * 查询职业
     *
     * @param careerId 职业主键
     * @return 职业
     */
    public MallCareer selectMallCareerByCareerId(Long careerId);

    /**
     * 查询职业列表
     *
     * @param mallCareer 职业
     * @return 职业集合
     */
    public List<MallCareer> selectMallCareerList(MallCareer mallCareer);

    /**
     * 新增职业
     *
     * @param mallCareer 职业
     * @return 结果
     */
    public int insertMallCareer(MallCareer mallCareer);

    /**
     * 修改职业
     *
     * @param mallCareer 职业
     * @return 结果
     */
    public int updateMallCareer(MallCareer mallCareer);

    /**
     * 删除职业
     *
     * @param careerId 职业主键
     * @return 结果
     */
    public int deleteMallCareerByCareerId(Long careerId);

    /**
     * 批量删除职业
     *
     * @param careerIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMallCareerByCareerIds(Long[] careerIds);

    /**
     * 根据排序查询职业列表
     *
     * @param sortType 排序类型：0-默认，1-从高到低，2-从低到高

     * @return 专业分类集合
     */
    public List<Map<String, Object>> selectCareerListByParams(@Param("sortType") Integer sortType, @Param("majorName")String majorName);

    /**
     * 查询职业列表-下拉框
     *
     * @return 职业集合
     */
    public List<MallCareer> getCareerDropDownList();
}
